==> vtigercrm-5.3.0p0.tgz: modules/Dashboard/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Dashboard/language/en_us.lang.php,v 1.4 2005/01/25 06:01:38 jack Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_SALES_STAGE_FORM_TITLE'=>'Funil Estágio de Vendas',
'LBL_SALES_STAGE_FORM_DESC'=>'Mostra as quantidades acumuladas da Oportunidade, por Estágio de Venda e Usuários selecionados, onde a data prevista de fechamento está dentro do intervalo de data especificado.',
'LBL_MONTH_BY_OUTCOME'=>'Funil de Vendas por Resultado Mensal',
'LBL_MONTH_BY_OUTCOME_DESC'=>'Mostra as quantidades acumuladas da Oportunidade, por Resultado Mensal, para usuários selecionados onde a expectativa da data de fechamento está dentro do intervalo de data especificado. O resultado é baseado no estágio das vendas, se foi Fechada com Sucesso, se o Fechamento foi Perdido ou algum outro valor.',
'LBL_LEAD_SOURCE_FORM_TITLE'=>'Todas as Oportunidades por Fonte de Lead',
'LBL_LEAD_SOURCE_FORM_DESC'=>'Mostra quantidades acumuladas da Oportunidade, por fonte selecionada de Lead, para usuários selecionados.',
'LBL_LEAD_SOURCE_BY_OUTCOME'=>'Todas as Oportunidades por Fonte de Lead e por Resultado',
'LBL_LEAD_SOURCE_BY_OUTCOME_DESC'=>'Mostra as quantidades acumuladas da Oportunidade por fonte selecionada de Lead, para usuários selecionados onde a data de fechamento prevista está dentro do limite de data especificado.O resultado é baseado no Estágio das Vendas, se foi Fechada com Sucesso, se o Fechamento foi Perdido ou algum outro valor.',
'LBL_PIPELINE_FORM_TITLE_DESC'=>'Mostra as quantidades acumuladas, por Estágios de Vendas selecionados, para suas Oportunidades onde a data de fechamento prevista está dentro do limite de data especificado.',
'LBL_DATE_RANGE'=>'A data limite é de ',
'LBL_DATE_RANGE_TO'=>'até ',
'ERR_NO_OPPS'=>'Por favor, crie algumas Oportunidades para ver o Gráfico de Oportunidades.',
'LBL_TOTAL_PIPELINE'=>'Total Funil de Vendas é',
'LBL_ALL_OPPORTUNITIES'=>'Resultado Total para todas as Oportunidades é',
'LBL_OPP_SIZE'=>'Valor Oportunidades em ',
'LBL_OPP_SIZE_VALUE'=>'1M',
'NTC_NO_LEGENDS'=>'Nada',
'LBL_LEAD_SOURCE_OTHER'=>'Outro',
'LBL_EDIT'=>'Editar',
'LBL_REFRESH'=>'Atualizar',
'LBL_CREATED_ON'=>'Última execução',
'LBL_OPPS_IN_STAGE'=>'Oportunidades cujo Estágio de Vendas é',
'LBL_OPPS_IN_LEAD_SOURCE'=>'Oportunidades cuja Origem do Lead é',
'LBL_OPPS_OUTCOME'=>'Oportunidades cujo Resultado é',
'LBL_USERS'=>'Usuários:',
'LBL_SALES_STAGES'=>'Estágios de Vendas:',
'LBL_LEAD_SOURCES'=>'Origem do Lead:',
'LBL_DATE_START'=>'Data Inicial:',
'LBL_DATE_END'=>'Data Final:',
//Added for 5.0
'LBL_NO_PERMISSION'=>'Seu perfil não permite que você veja o Gráfico deste Módulo',
'LBL_NO_PERMISSION_FIELD'=>'Seu perfil não permite que você veja o Gráfico deste Módulo ou deste Campo',

"leadsource" => "Leads por Fonte",
"leadstatus" => "Leads por Status",
"leadindustry" => "Leads por Atividade",
"salesbyleadsource" => "Vendas por Fonte Lead",
"salesbyaccount" => "Vendas por Contas",
"salesbyuser" => "Vendas por Usuário",
"salesbyteam"=>"Vendas por Equipe",
"accountindustry" => "Contas por Atividade",
"productcategory" => "Produtos por Categoria",
"productbyqtyinstock" => "Produtos por Quantidade em Estoque",
"productbypo" => "Produtos por Pedido Compra",
"productbyquotes" => "Produtos por Cotação",
"productbyinvoice" => "Produtos por Fatura",
"sobyaccounts" => "Pedidos Vendas por Contas",
"sobystatus" => "Pedidos Vendas por Status",
"pobystatus" => "Pedido Compra por Status",
"quotesbyaccounts" => "Cotações por Contas",
"quotesbystage" => "Cotações por Estágio",
"invoicebyacnts" => "Faturas por Contas",
"invoicebystatus" => "Faturas por Status",
"ticketsbystatus" => "Tickets por Status",
"ticketsbypriority" => "Tickets por Prioridade",
"ticketsbycategory" => "Tickets por Categoria",
"ticketsbyuser"=>"Tickets por Usuário",
"ticketsbyteam"=>"Tickets por Equipe",
"ticketsbyproduct"=>"Tickets por Produto",
"contactbycampaign"=>"Contatos por Campanha",
"ticketsbyaccount"=>"Tickets por Conta",
"ticketsbycontact"=>"Tickets por Contato",

'LBL_DASHBRD_HOME'=>'Painel Principal',
'LBL_HORZ_BAR_CHART'=>'Gráfico Barras Horizontal',
'LBL_VERT_BAR_CHART'=>'Gráfico Barras Vertical',
'LBL_PIE_CHART'=>'Gráfico Pizza',
'LBL_NO_DATA'=>'Dados não disponíveis',
'DashboardHome'=>'Página Painel',
'GRIDVIEW'=>'Visualizar Grade',
'NORMALVIEW'=>'Visualizar Normal',
'VIEWCHART'=>'Visualizar Gráfico',
'LBL_DASHBOARD'=>'Painel',

// Added/Updated for vtiger CRM 5.0.4
"Approved"=>"Aprovado",
"Created"=>"Criado",
"Cancelled"=>"Cancelado",
"Delivered"=>"Entregue",
"Received Shipment"=>"Entrega Recebida",
"Sent"=>"Enviar",
"Credit Invoice"=>"Crédito Fatura",
"Paid"=>"Pago",
"Un Assigned"=>"Un Assigned",
"Cold Call"=>"Cold Call",
"Existing Customer"=>"Cliente Existente",
"Self Generated"=>"Auto-Gerado",
"Employee"=>"Empregado",
"Partner"=>"Parceiro",
"Public Relations"=>"Relações Públicas",
"Direct Mail"=>"Mala Direta",
"Conference"=>"Conferência",
"Trade Show"=>"Feiras Negócios",
"Web Site"=>"Web Site",
"Word of mouth"=>"Boca-Boca",
"Other"=>"Outro",
"--None--"=>"Nada",
"Attempted to Contact"=>"Tentativa Contato",
"Cold"=>"Frio",
"Contact in Future"=>"Contactar no Futuro",
"Contacted"=>"Contactado",
"Hot"=>"Quente",
"Junk Lead"=>"Descartado",
"Lost Lead"=>"Perdido",
"Not Contacted"=>"Não Contactado",
"Pre Qualified"=>"Pré-Qualificado",
"Qualified"=>"Qualificado",
"Warm"=>"Morno",
"Apparel"=>"Vestuário",
"Banking"=>"Banco",
"Biotechnology"=>"Biotecnologia",
"Chemicals"=>"Química",
"Communications"=>"Comunicações",
"Construction"=>"Construção",
"Consulting"=>"Consultoria",
"Education"=>"Educação",
"Electronics"=>"Eletrônica",
"Energy"=>"Energia",
"Engineering"=>"Engenharia",
"Entertainment"=>"Entretenimento",
"Environmental"=>"Meio Ambiente",
"Finance"=>"Finanças",
"Food & Beverage"=>"Alimentação & Bebidas",
"Government"=>"Governo",
"Healthcare"=>"Saúde",
"Hospitality"=>"Hotelaria",
"Insurance"=>"Seguros",
"Machinery"=>"Mecânica",
"Manufacturing"=>"Indústria",
"Media"=>"Mídia",
"Not For Profit"=>"ONG",
"Recreation"=>"Recreação",
"Retail"=>"Comércio",
"Shipping"=>"Transporte Marítimo",
"Technology"=>"Tecnologia",
"Telecommunications"=>"Telecomunicações",
"Transportation"=>"Transportes",
"Utilities"=>"Serviço Público",
"Hardware"=>"Hardware",
"Software"=>"Software",
"CRM Applications"=>"Aplicações CRM",
"Open"=>"Aberto",
"In Progress"=>"Em Andamento",
"Wait For Response"=>"Aguarando Resposta",
"Closed"=>"Fechado",
"Low"=>"Baixa",
"Normal"=>"Normal",
"High"=>"Alta",
"Urgent"=>"Urgente",
"Big Problem"=>"Problema Grande",
"Small Problem"=>"Problema Pequeno",
"Other Problem"=>"Outro Problema",
"Accepted"=>"Aceito",
"Rejected"=>"Rejeitado",
"Prospecting"=>"Prospectando",
"Qualification"=>"Qualificação",
"Needs Analysis"=>"Necessita Análise",
"Value Proposition"=>"Proposto Valor",
"Id. Decision Makers"=>"Identif. Decisor",
"Perception Analysis"=>"Análise Percepção",
"Proposal/Price Quote"=>"Proposta/Cotação",
"Negotiation/Review"=>"Negocição/Análise",
"Closed Won"=>"Fechado Vencido",
"Closed Lost"=>"Fechado Perdido",

);

?>

==> vtigercrm-5.4.0.tgz: modules/Dashboard/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Dashboard/language/en_us.lang.php,v 1.4 2005/01/25 06:01:38 jack Exp $
 * Description:  Defines the English language pack for the DashBoard module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_SALES_STAGE_FORM_TITLE'=>'Funil Estágio de Vendas',
'LBL_SALES_STAGE_FORM_DESC'=>'Mostra as quantidades acumuladas da Oportunidade, por Estágio de Venda e Usuários selecionados, onde a data prevista de fechamento está dentro do intervalo de data especificado.',
'LBL_MONTH_BY_OUTCOME'=>'Funil de Vendas por Resultado Mensal',
'LBL_MONTH_BY_OUTCOME_DESC'=>'Mostra as quantidades acumuladas da Oportunidade, por Resultado Mensal, para usuários selecionados onde a expectativa da data de fechamento está dentro do intervalo de data especificado. O resultado é baseado no estágio das vendas, se foi Fechada com Sucesso, se o Fechamento foi Perdido ou algum outro valor.',
'LBL_LEAD_SOURCE_FORM_TITLE'=>'Todas as Oportunidades por Fonte de Lead',
'LBL_LEAD_SOURCE_FORM_DESC'=>'Mostra quantidades acumuladas da Oportunidade, por fonte selecionada de Lead, para usuários selecionados.',
'LBL_LEAD_SOURCE_BY_OUTCOME'=>'Todas as Oportunidades por Fonte de Lead e por Resultado',
'LBL_LEAD_SOURCE_BY_OUTCOME_DESC'=>'Mostra as quantidades acumuladas da Oportunidade por fonte selecionada de Lead, para usuários selecionados onde a data de fechamento prevista está dentro do limite de data especificado.O resultado é baseado no Estágio das Vendas, se foi Fechada com Sucesso, se o Fechamento foi Perdido ou algum outro valor.',
'LBL_PIPELINE_FORM_TITLE_DESC'=>'Mostra as quantidades acumuladas, por Estágios de Vendas selecionados, para suas Oportunidades onde a data de fechamento prevista está dentro do limite de data especificado.',
'LBL_DATE_RANGE'=>'A data limite é de ',
'LBL_DATE_RANGE_TO'=>'até ',
'ERR_NO_OPPS'=>'Por favor, crie algumas Oportunidades para ver o Gráfico de Oportunidades.',
'LBL_TOTAL_PIPELINE'=>'Total Funil de Vendas é',
'LBL_ALL_OPPORTUNITIES'=>'Resultado Total para todas as Oportunidades é',
'LBL_OPP_SIZE'=>'Valor Oportunidades em ',
'LBL_OPP_SIZE_VALUE'=>'1M',
'NTC_NO_LEGENDS'=>'Nada',
'LBL_LEAD_SOURCE_OTHER'=>'Outro',
'LBL_EDIT'=>'Editar',
'LBL_REFRESH'=>'Atualizar',
'LBL_CREATED_ON'=>'Última execução',
'LBL_OPPS_IN_STAGE'=>'Oportunidades cujo Estágio de Vendas é',
'LBL_OPPS_IN_LEAD_SOURCE'=>'Oportunidades cuja Origem do Lead é',
'LBL_OPPS_OUTCOME'=>'Oportunidades cujo Resultado é',
'LBL_USERS'=>'Usuários:',
'LBL_SALES_STAGES'=>'Estágios de Vendas:',
'LBL_LEAD_SOURCES'=>'Origem do Lead:',
'LBL_DATE_START'=>'Data Inicial:',
'LBL_DATE_END'=>'Data Final:',
//Added for 5.0
'LBL_NO_PERMISSION'=>'Seu perfil não permite que você veja o Gráfico deste Módulo',
'LBL_NO_PERMISSION_FIELD'=>'Seu perfil não permite que você veja o Gráfico deste Módulo ou deste Campo',

"leadsource" => "Leads por Fonte",
"leadstatus" => "Leads por Status",
"leadindustry" => "Leads por Atividade",
"salesbyleadsource" => "Vendas por Fonte Lead",
"salesbyaccount" => "Vendas por Organização",
"salesbyuser" => "Vendas por Usuário",
"salesbyteam"=>"Vendas por Equipe",
"accountindustry" => "Organizações por Atividade",
"productcategory" => "Produtos por Categoria",
"productbyqtyinstock" => "Produtos por Quantidade em Estoque",
"productbypo" => "Produtos por Pedido Compra",
"productbyquotes" => "Produtos por Cotação",
"productbyinvoice" => "Produtos por Fatura",
"sobyaccounts" => "Pedidos Vendas por Organização",
"sobystatus" => "Pedidos Vendas por Status",
"pobystatus" => "Pedido Compra por Status",
"quotesbyaccounts" => "Cotações por Organização",
"quotesbystage" => "Cotações por Estágio",
"invoicebyacnts" => "Faturas por Organização",
"invoicebystatus" => "Faturas por Status",
"ticketsbystatus" => "Tickets por Status",
"ticketsbypriority" => "Tickets por Prioridade",
"ticketsbycategory" => "Tickets por Categoria",
"ticketsbyuser"=>"Tickets por Usuário",
"ticketsbyteam"=>"Tickets por Equipe",
"ticketsbyproduct"=>"Tickets por Produto",
"contactbycampaign"=>"Contatos por Campanha",
"ticketsbyaccount"=>"Tickets por Organização",
"ticketsbycontact"=>"Tickets por Contato",

'LBL_DASHBRD_HOME'=>'Painel Principal',
'LBL_HORZ_BAR_CHART'=>'Gráfico Barras Horizontal',
'LBL_VERT_BAR_CHART'=>'Gráfico Barras Vertical',
'LBL_PIE_CHART'=>'Gráfico Pizza',
'LBL_NO_DATA'=>'Dados não disponíveis',
'DashboardHome'=>'Página Painel',
'GRIDVIEW'=>'Visualizar Grade',
'NORMALVIEW'=>'Visualizar Normal',
'VIEWCHART'=>'Visualizar Gráfico',
'LBL_DASHBOARD'=>'Painel',

// Added/Updated for vtiger CRM 5.0.4
"Approved"=>"Aprovado",
"Created"=>"Criado",
"Cancelled"=>"Cancelado",
"Delivered"=>"Entregue",
"Received Shipment"=>"Entrega Recebida",
"Sent"=>"Enviar",
"Credit Invoice"=>"Crédito Fatura",
"Paid"=>"Pago",
"Un Assigned"=>"Un Assigned",
"Cold Call"=>"Cold Call",
"Existing Customer"=>"Cliente Existente",
"Self Generated"=>"Auto-Gerado",
"Employee"=>"Empregado",
"Partner"=>"Parceiro",
"Public Relations"=>"Relações Públicas",
"Direct Mail"=>"Mala Direta",
"Conference"=>"Conferência",
"Trade Show"=>"Feiras Negócios",
"Web Site"=>"Web Site",
"Word of mouth"=>"Boca-Boca",
"Other"=>"Outro",
"--None--"=>"Nada",
"Attempted to Contact"=>"Tentativa Contato",
"Cold"=>"Frio",
"Contact in Future"=>"Contactar no Futuro",
"Contacted"=>"Contactado",
"Hot"=>"Quente",
"Junk Lead"=>"Descartado",
"Lost Lead"=>"Perdido",
"Not Contacted"=>"Não Contactado",
"Pre Qualified"=>"Pré-Qualificado",
"Qualified"=>"Qualificado",
"Warm"=>"Morno",
"Apparel"=>"Vestuário",
"Banking"=>"Banco",
"Biotechnology"=>"Biotecnologia",
"Chemicals"=>"Química",
"Communications"=>"Comunicações",
"Construction"=>"Construção",
"Consulting"=>"Consultoria",
"Education"=>"Educação",
"Electronics"=>"Eletrônica",
"Energy"=>"Energia",
"Engineering"=>"Engenharia",
"Entertainment"=>"Entretenimento",
"Environmental"=>"Meio Ambiente",
"Finance"=>"Finanças",
"Food & Beverage"=>"Alimentação & Bebidas",
"Government"=>"Governo",
"Healthcare"=>"Saúde",
"Hospitality"=>"Hotelaria",
"Insurance"=>"Seguros",
"Machinery"=>"Mecânica",
"Manufacturing"=>"Indústria",
"Media"=>"Mídia",
"Not For Profit"=>"ONG",
"Recreation"=>"Recreação",
"Retail"=>"Comércio",
"Shipping"=>"Transporte Marítimo",
"Technology"=>"Tecnologia",
"Telecommunications"=>"Telecomunicações",
"Transportation"=>"Transportes",
"Utilities"=>"Serviço Público",
"Hardware"=>"Hardware",
"Software"=>"Software",
"CRM Applications"=>"Aplicações CRM",
"Open"=>"Aberto",
"In Progress"=>"Em Andamento",
"Wait For Response"=>"Aguarando Resposta",
"Closed"=>"Fechado",
"Low"=>"Baixa",
"Normal"=>"Normal",
"High"=>"Alta",
"Urgent"=>"Urgente",
"Big Problem"=>"Problema Grande",
"Small Problem"=>"Problema Pequeno",
"Other Problem"=>"Outro Problema",
"Accepted"=>"Aceito",
"Rejected"=>"Rejeitado",
"Prospecting"=>"Prospectando",
"Qualification"=>"Qualificação",
"Needs Analysis"=>"Necessita Análise",
"Value Proposition"=>"Proposta Valor",
"Id. Decision Makers"=>"Identif. Decisor",
"Perception Analysis"=>"Análise Percepção",
"Proposal/Price Quote"=>"Proposta/Cotação",
"Negotiation/Review"=>"Negocição/Análise",
"Closed Won"=>"Fechado Vencido",
"Closed Lost"=>"Fechado Perdido",

);

?>
